// ==================================================================
//
// Program Name
//  MQAttr
//
// Last date of modification
//  1 Oct 2000
//
// Description
//  This java class will output the attributes of a queue.
//
// Sample Command Line Parameters
//  -h 127.0.0.1 -p 1414 -c CLIENT.CHANNEL -m MQA1 -q TEST.QUEUE
//
// Copyright(C), Roger Lacroix, Capitalware
//
// ------------------------------------------------------------------

import com.ibm.mq.*;
import java.io.IOException;
import java.util.Hashtable;
import java.io.*;
import java.util.GregorianCalendar;
import java.util.Calendar;

public class MQAttr
{
   private MQQueueManager _queueManager = null;
   private Hashtable params = null;
   public int port = 1414;
   public String hostname   = "127.0.0.1";
   public String channel    = "CLIENT.TO.MQA1";
   public String qManager    = "MQA1";
   public String inputQName = "SYSTEM.DEFAULT.LOCAL.QUEUE";

 public MQAttr()
 {
   super();
 }
 private boolean allParamsPresent()
 {
   boolean b = params.containsKey("-h") &&
    params.containsKey("-p") &&
    params.containsKey("-c") &&
    params.containsKey("-m") &&
    params.containsKey("-q");
   if (b)
   {
    try
    {
     port = Integer.parseInt((String) params.get("-p"));
    }
    catch (NumberFormatException e)
    {
     b = false;
    }
         // Set up MQ environment
    hostname = (String) params.get("-h");
    channel  = (String) params.get("-c");
    qManager = (String) params.get("-m");
    inputQName = (String) params.get("-q");

   }
   return b;
 }
 private void getAttr() throws MQException
 {
   // int openOptions = MQC.MQOO_INQUIRE + MQC.MQOO_FAIL_IF_QUIESCING + MQC.MQOO_INPUT_SHARED;
   int openOptions = MQC.MQOO_INQUIRE + MQC.MQOO_FAIL_IF_QUIESCING;
     int InhibitGet;

   String dType="Nothing";
   String qType="Nothing";
   String iPut="Nothing";
   String iGet="Nothing";
   String share="Nothing";
   String tControl = "Nothing";
   String tType = "Nothing";
   int    qTypeNum=0;
//   GregorianCalendar DateTime;
   String Date;
   String Time;

   MQQueue queue = _queueManager.accessQueue( inputQName,
                                   openOptions,
                                   null,           // default q manager
                                   null,           // no dynamic q name
                                   null );         // no alternate user id


   System.out.println("MQAttr v1.0 connected.\n");

   try
   {

   qTypeNum = queue.getQueueType();

   switch (qTypeNum)
   {
     case MQC.MQQT_LOCAL:
             qType = "Local";
            break;

     case MQC.MQQT_MODEL:
             qType = "Model";
         break;

     case MQC.MQQT_ALIAS:
             qType = "Alias";
         break;

     case MQC.MQQT_REMOTE:
             qType = "Remote";
         break;

     // case MQC.MQQT_CLUSTER:
     case 7:
             qType = "Cluster";
         break;

     default :
             qType = "Unknown";
         break;
   }

   if ( (qTypeNum == MQC.MQQT_LOCAL )  ||
      (qTypeNum == MQC.MQQT_MODEL )  ||
      (qTypeNum == MQC.MQQT_REMOTE ) ||
      (qTypeNum == MQC.MQQT_ALIAS ) )
   {
     if (queue.getInhibitPut() == MQC.MQQA_PUT_ALLOWED)
        iPut = "Allowed";
     else
       iPut = "Inhibited";
   }


   if ( (qTypeNum == MQC.MQQT_LOCAL )  ||
      (qTypeNum == MQC.MQQT_MODEL )  ||
      (qTypeNum == MQC.MQQT_ALIAS ) )

   {
     if (queue.getInhibitGet() == MQC.MQQA_GET_ALLOWED)
        iGet = "Allowed";
     else
       iGet = "Inhibited";
   }

   System.out.println("Queue Name: " + inputQName);
   System.out.println("Queue Type: " + qType );

   if ( (qTypeNum == MQC.MQQT_LOCAL) || (qTypeNum == MQC.MQQT_MODEL) )
   {
     switch (queue.getDefinitionType())
     {
     case MQC.MQQDT_PREDEFINED :
             dType = "Predefined";
         break;
     case MQC.MQQDT_PERMANENT_DYNAMIC :
             dType = "Permanent";
         break;
     case MQC.MQQDT_TEMPORARY_DYNAMIC :
             dType = "Temporary";
         break;
     default :
             dType = "Unknown";
         break;
     }

     if (queue.getShareability() == MQC.MQQA_SHAREABLE )
        share = "Shareable";
     else
       share = "Not Shareable";

     if (queue.getTriggerControl() == MQC.MQTC_OFF )
        tControl = "OFF";
     else
       tControl = "ON";

     switch (queue.getTriggerType())
     {
     case MQC.MQTT_NONE :
             tType = "None";
         break;
     case MQC.MQTT_FIRST:
             tType = "First";
         break;
     case MQC.MQTT_EVERY:
             tType = "Every";
         break;
     case MQC.MQTT_DEPTH:
             tType = "Depth";
         break;
     default :
             tType = "Unknown";
         break;
     }

     System.out.println("Definition Type: " + dType );
     System.out.println("Current Depth: " + queue.getCurrentDepth() );
     System.out.println("Get Messages: " + iGet );
     System.out.println("Put Messages: " + iPut );
     System.out.println("Maximum Depth: " + queue.getMaximumDepth() );
     System.out.println("Maximum Message Length: " + queue.getMaximumMessageLength() );
     System.out.println("Open Input Count:  " + queue.getOpenInputCount() );
     System.out.println("Open Output Count: " + queue.getOpenOutputCount() );
     System.out.println("Shareability: " + share );
     System.out.println("Trigger Control: " + tControl );
     System.out.println("Trigger Type: " + tType );
     System.out.println("Trigger Data: " + queue.getTriggerData() );
     System.out.println("Trigger Depth: " + queue.getTriggerDepth() );
     System.out.println("Trigger Message Priority: " + queue.getTriggerMessagePriority() );

   } // if


   if (qTypeNum == MQC.MQQT_REMOTE)
   {
     System.out.println("Put Messages: " + iPut );
   }


   if (qTypeNum == MQC.MQQT_ALIAS)
   {
     System.out.println("Get Messages: " + iGet );
     System.out.println("Put Messages: " + iPut );
   }

   } // try

   catch (MQException e)
   {
    if ( (e.completionCode == 1 ) && (e.reasonCode == 2068) )
    {

    }
    else
    {
       System.out.println("MQ Error:Completion code:" + e.completionCode + " reason code: " + e.reasonCode );
       System.exit(1);
    }
   }

   queue.close();
   _queueManager.disconnect();
 }
 private void init(String[] args) throws IllegalArgumentException
 {
   params = new Hashtable(5);
   if (args.length > 0 && (args.length % 2) == 0)
   {
    for (int i = 0; i < args.length; i+=2)
    {
     params.put(args[i], args[i+1]);
    }
   }
   else
   {
    throw new IllegalArgumentException();
   }
   if (allParamsPresent())
   {
      // Set up MQ environment
    MQEnvironment.hostname = hostname;
    MQEnvironment.channel  = channel;
    MQEnvironment.port     = port;

   }
   else
   {
    throw new IllegalArgumentException();
   }
 }
 public static void main(String[] args)
 {

   MQAttr mqattr = new MQAttr();

   try
   {
    mqattr.init(args);
    mqattr.selectQMgr();
    mqattr.getAttr();
   }
   catch (IllegalArgumentException e)
   {
    System.out.println("Usage: java MQAttr <-h host> <-p port> <-c channel> <-m QueueManagerName> <-q QueueName>");
    System.exit(1);
   }
   catch (MQException e)
   {
    System.out.println(e);
    System.exit(1);
   }
 }
 private void selectQMgr() throws MQException
 {
   _queueManager = new MQQueueManager(qManager);
 }

}
